<?php

namespace Buzzlab\Controllers\Admin;

use Buzzlab\BackOffice\Request;
use Buzzlab\Controllers\Controller;
use Buzzlab\Lib\CurlRequest;
use Buzzlab\Models\EmailHistory;
use Buzzlab\Models\SmsHistory;
use Buzzlab\Models\Contact;
use Buzzlab\Models\Group;

class AdminController extends Controller{

    public function dashboard()
    {
        $pageTitle = 'Dashboard';

        $smsGateway  = ['clickatell', 'infobip', 'messageBird', 'nexmo', 'smsBroadcast', 'twilio', 'textMagic', 'custom'];
        
        $emailSender = ['phpmail', 'smtp', 'mailjet', 'sendgrid'];

        $widget['total_processed_email'] = EmailHistory::count();
        $widget['total_success_email']   = EmailHistory::where('status',  1)->count();
        $widget['total_pending_email']   = EmailHistory::where('status',  2)->count();  //scheduled
        $widget['total_failed_email']    = EmailHistory::where('status',  9)->count();

        $widget['total_processed_sms'] = SmsHistory::count();
        $widget['total_success_sms']   = SmsHistory::where('status',  1)->count();
        $widget['total_pending_sms']   = SmsHistory::where('status',  2)->count();  //scheduled
        $widget['total_failed_sms']    = SmsHistory::where('status',  9)->count();

        $widget['total_contacts']        = Contact::count();
        $widget['total_email_contacts']  = Contact::where('email', '!=', null)->count();
        $widget['total_mobile_contacts'] = Contact::where('mobile', '!=', null)->count();
        $widget['total_banned_contacts'] = Contact::where('status', 0)->count();

        $widget['total_groups']        = Group::count();
        $widget['total_email_groups']  = Group::where('type', 1)->count();
        $widget['total_mobile_groups'] = Group::where('type', 2)->count();
        $widget['total_banned_groups'] = Group::where('status', 0)->count();
        

        $this->view('admin/dashboard', compact('pageTitle', 'widget', 'smsGateway', 'emailSender'));
    }

    public function requestReport()
    {
        $pageTitle = 'Your Listed Report & Request';
        $arr['app_name'] = buzz_system_details()['name'];
        $arr['app_url'] = home_url();
        $arr['purchase_code'] = get_option('buzz_purchase_code','VISERLAB');
        $url = "https://license.viserlab.com/issue/get?".http_build_query($arr);
        $response = CurlRequest::curlContent($url);
        $response = json_decode($response);
        if ($response->status == 'error') {
            $notify[] = ['error','Something went wrong'];
            buzz_set_notify($notify);
            buzz_redirect(menu_page_url(BUZZLAB_PLUGIN_NAME,false));
        }
        $reports = $response->message[0];
        $this->view('admin/reports',compact('pageTitle','reports'));
    }

    public function requestReportSubmit()
    {
        $request = new Request;
        $request->validate([
            'type'=>'required|in:bug,feature',
            'message'=>'required'
        ]);

        $url = 'https://license.viserlab.com/issue/add';
        $arr['app_name'] = buzz_system_details()['name'];
        $arr['app_url'] = home_url();
        $arr['purchase_code'] = get_option('buzz_purchase_code','VISERLAB');
        $arr['req_type'] = $request->type;
        $arr['message'] = $request->message;
        $response = CurlRequest::curlPostContent($url,$arr);
        $response = json_decode($response);
        if ($response->status == 'error') {
            $notify[] = ['error','Something went wrong'];
            buzz_set_notify($notify);
            buzz_back();
        }
        $notify[] = ['success', $response->message];
        buzz_set_notify($notify);
        buzz_back();
    }

    public function download()
    {
        $file = buzz_request()->file_path;
        $file = buzz_decrypt($file);
        $extension = pathinfo($file, PATHINFO_EXTENSION);
        $title     = buzz_title_to_key(get_bloginfo('name')) . '_attachments.' . $extension;
        $mimetype  = mime_content_type($file);
        header('Content-Disposition: attachment; filename="' . $title);
        header("Content-Type: " . $mimetype);
        ob_clean();
        flush();
        return readfile($file);
    }

}