<?php

namespace Buzzlab\Controllers\Admin;

use Buzzlab\BackOffice\Request;
use Buzzlab\BackOffice\Validator\Validator;
use Buzzlab\Controllers\Controller;
use Buzzlab\Models\Contact;

class ContactController extends Controller
{
    public function index()
    {
        $pageTitle = 'Manage All Contacts';
        $query     = Contact::orderBy('id', 'desc')->filter(['name', 'email', 'mobile', 'status']);
        $request   = new Request();

     
        if ($request->status == "banned") {
            $pageTitle = 'All Banned Contacts';
            $query = $query->where('status', 0);
        }
        $contactType  = 'all';
        $contactCount = $query->count();
        $columns      = $query->columns();
        $contacts     = $query->paginate(buzz_paginate());
        $this->view('admin/contact/index', compact('pageTitle', 'contacts', 'contactType','contactCount','columns'));
    }

    public function emailContact()
    {
        $pageTitle    = 'Manage Email Contacts';
        $contactType  = "email";
        $query        = Contact::where('email', '!=', null)->orderBy('id', 'DESC')->filter(['name', 'email', 'status']);
        $contactCount = $query->count();
        $columns      = $query->columns();
        $contacts     = $query->paginate(buzz_paginate());
        $this->view('admin/contact/index', compact('pageTitle', 'contacts', 'contactType','contactCount','columns'));
    }

    public function smsContact()
    {
        $pageTitle    = 'Manage SMS Contacts';
        $contactType  = "mobile";
        $query        = Contact::where('mobile', '!=', null)->orderBy('id', 'DESC')->filter(['name', 'mobile', 'status']);
        $contactCount = $query->count();
        $columns      = $query->columns();
        $contacts     = $query->paginate(buzz_paginate());
        $this->view('admin/contact/index', compact('pageTitle', 'contacts', 'contactType','contactCount','columns'));
    }

    public function status()
    {
        $request = new Request();
        $contact =  Contact::find($request->id);
        if (!$contact) {
            buzz_abort(404);
        }
        $contact->status = $contact->status ? 0 : 1;
        $contact->save();
        $notify[] = ['success', 'Status updated successfully'];
        buzz_set_notify($notify);
        buzz_back();
    }


    public function store()
    {
        $request = new Request();
        $request->validate([
            'contact_type'  => 'required',
            'email' => 'required_if:contact_type,email|email',
            'mobile' => 'required_if:contact_type,mobile',
        ]);

        $contact         = new Contact();
        $contact->name   = sanitize_text_field($request->name);
        $contact->email  = sanitize_email($request->email);
        $contact->mobile = sanitize_text_field($request->mobile);
        $contact->created_at   = current_time('mysql');
        $contact->save();
        $notify[] = ['success', 'Contact added successfully'];
        buzz_set_notify($notify);
        buzz_back();
    }

    public function update()
    {
        $request = new Request();
        $request->validate([
            'contact_type' => 'required',
            'email'        => 'required_if:contact_type,email|email',
            'mobile'       => 'required_if:contact_type,mobile',
        ]);

        $contact  = Contact::findOrFail($request->id);
        if (!$contact) {
            buzz_abort(404);
        }

        $contact->name   = sanitize_text_field($request->name);
        $contact->email  = sanitize_email($request->email);
        $contact->mobile = sanitize_text_field($request->mobile);
        $contact->updated_at   = current_time('mysql');
        $contact->save();
        $notify[] = ['success', 'Contact updated successfully'];
        buzz_set_notify($notify);
        buzz_back();
    }

    public function importContact()
    {
        $request = new Request();
        $validations = Validator::make([
            'file'=>'required|file|mimes:csv,xlsx,txt',
            'contact_type'=>'required|in:all,mobile,email'
        ]);

        if (!empty($validations['errors'])) {
            wp_send_json([
                'success' => false,
                'errors'  =>$validations['errors']
            ]);
            die;
        }

        if ($request->contact_type == 'email') {
            $columns       = ['email'];
            $uniqueColumns = ['email'];
        } elseif ($request->contact_type == 'mobile') {
            $columns       = ['mobile'];
            $uniqueColumns = ['mobile'];
        } else {
            $columns       = ['name', 'email', 'mobile'];
            $uniqueColumns = ['email', 'mobile'];
        }
        $notify = [];
        
        try {
            $import = buzz_import_file_reader($request->file, $columns, $uniqueColumns);
            $notify = $import->notifyMessage();
        } catch (\Exception $ex) {
            $notify['success'] = false;
            $notify['message'] = $ex->getMessage();
        }

        wp_send_json($notify);
        die;
    }

    public function export()
    {
        if (!current_user_can('manage_options')) {
            $notify[] = ['error','You\'ve no access to visit this route'];
            buzz_set_notify($notify);
            buzz_back();
        }
        $request = new Request();
        $request->validate([
            'columns'=>'required',
            'export_item'=>'required|integer',
            'contact_type'=>'required|in:all,mobile,email'
        ]);
        $contact                        = new Contact();
        $contact->exportColumns         = $request->columns;
        $contact->fileName              = $request->contact_type . '_contact.csv';
        $contact->exportItem            = $request->export_item;
        $contact->orderBy               = $request->order_by ? "ASC" : 'DESC';
        $contact->export();
        die;
    }
}
