<?php

namespace Buzzlab\Controllers\Admin;

use Buzzlab\Controllers\Controller;
use Buzzlab\BackOffice\Request;
use Buzzlab\Models\Contact;
use Buzzlab\Models\Group;
use Buzzlab\Models\GroupContact;
use Buzzlab\Models\Batch;
use Buzzlab\Models\EmailHistory;
use Buzzlab\BackOffice\Validator\Validator;

class EmailController extends Controller
{
    public function history()
    {
        $pageTitle = 'Email History';
        $request = new Request();
        $query = EmailHistory::orderBy('id', 'DESC');
        if ($request->batch_id) {
            $batch     = Batch::where('id', $request->batch_id)->first();
            $pageTitle = "Email History For Batch: " . $batch->batch_id;
            $query = $query->where('batch_id', $batch->id);
        } elseif ($request->status == 1) {
            $logs      = $query->where('status', 1);
        } elseif ($request->status == 2) {
            $logs      = $query->where('status', 2);
        } elseif ($request->status == 9) {
            $logs      = $query->where('status', 9);
        }
        $logs = $query->paginate(buzz_paginate());
        $this->view('admin/email/history', compact('pageTitle', 'logs'));
    }


    public function emailView()
    {
        $request   = new Request();
        $email     = EmailHistory::findOrFail($request->id);
        $pageTitle = "Email Details";
        $this->view('admin/email/details', compact('pageTitle', 'email'));
    }


    public function sendEmailForm()
    {
        $pageTitle = 'Send Email';
        $groups    = Group::where('type', 1)->where('status', 1)->get();
        $this->view('admin/email/send_form', compact('pageTitle', 'groups'));
    }


    public function merge()
    {
        $request = new Request();
        $validations = Validator::make([
            'file'=>'file|size:3072|mimes:csv,xlsx,txt',
        ]);
        if (!empty($validations['errors'])) {
            wp_send_json([
                'success' => false,
                'errors'  => $validations['errors']
            ]);
            die;
        }
        $emailFromFile = [];
        if ($request->hasFile('file')) {
            try {
                $fileRead = buzz_import_file_reader($request->file, ['email'], [], false);
                $emailReadFromFile = $fileRead->getReadData();
                if (count($emailReadFromFile)) {
                    foreach ($emailReadFromFile as $email) {
                        $emailFromFile[] = @$email[0];
                    }
                }
            } catch (\Exception $ex) {
                $notify['success'] = false;
                $notify['errors'] = [$ex->getMessage()];
                wp_send_json($notify);
                die;
            }
        }
        $contactId        = $request->contact_id ?? [];
        $emailFromContact = Contact::whereIn('id', $contactId)->get();
        $emailContacts = [];
        foreach ($emailFromContact as $contact) {
            $emailContacts[] = $contact->email;
        }
        $groupId          = $request->group_id ?? [];
        $emailFromGroup   = GroupContact::whereIn('group_id', $groupId)->get();

        foreach ($emailFromGroup as $group) {
            $contact = Contact::where('status', 1)->findOrFail($group->contact_id);
            $emailContacts[] = $contact->email;
        }
        $emailContacts  = array_merge($emailContacts, $emailFromFile);
        $emailContacts = array_unique($emailContacts);
        if (count($emailContacts) <= 0) {
            return wp_send_json([
                'success' => false,
                'errors'  => ["At least one email required"]
            ]);
            die;
        }

        buzz_session()->put('EMAIL_FOR_SEND', $emailContacts);
        return wp_send_json([
            'success' => true,
            'emails'  => $emailContacts
        ]);
    }

    public function send()
    {
        $request = new Request();
        $validations = Validator::make([
            'will_be_sent' => 'required|in:1,2',
            'message'      => 'required',
            'subject'      => 'required'
        ]);
        if (!empty($validations['errors'])) {
            wp_send_json([
                'success' => false,
                'errors'  => $validations['errors']
            ]);
            die;
        }
        $batch = Batch::where('batch_id', $request->batch_id)->first();
        if (!$batch) {
            $batch                      = new Batch();
            $batch->type                = 1;
            $batch->batch_id            = $request->batch_id;
            $batch->total               = count(buzz_session()->get('EMAIL_FOR_SEND'));
            $batch->schedule            = buzz_date()->now();
            $batch->sender              = get_option('buzz_mail_config')['name'];
        }
        $contact  = Contact::where('email', $request->email)->first();
        $emailHistory                   = new EmailHistory();
        $emailHistory->contact_id       = $contact ? $contact->id : 0;
        $emailHistory->email            = $request->email;
        $emailHistory->message          = $request->message;
        $emailHistory->subject          = $request->subject;
        $emailHistory->schedule         = buzz_date()->parse($request->date)->toDateTime();
        $emailHistory->sender           = get_option('buzz_mail_config')['name'];
        if ($request->will_be_sent == 1) {
            $receiverName = explode('@', $emailHistory->email)[0];
            $user = [
                'display_name' => $receiverName,
                'user_email'   => $emailHistory->email
            ];

            buzz_notify($user, 'DEFAULT', [
                'subject' => $emailHistory->subject,
                'message' => $emailHistory->message
            ], ['email'], false);

            if (buzz_session()->has('mail_error')) {
                $emailHistory->status   = 9;
                $emailHistory->fail_reason = buzz_session()->get('mail_error');
                buzz_session()->forget('mail_error');
                $batch->total_fail++;
            } else {
                $emailHistory->status  = 1;
                $batch->total_success++;
            }
            $emailHistory->sent_time   = buzz_date()->now();
            $batch->status              = 1;
        }
        $batch->save();
        $emailHistory->batch_id         = $batch->id;
        $emailHistory->save();
        wp_send_json([
            'success' => true
        ]);
    }
}
