<?php

namespace Buzzlab\Controllers\Admin;

use Buzzlab\BackOffice\Request;
use Buzzlab\Controllers\Controller;
use Intervention\Image\ImageManager as Image;

class GeneralSettingController extends Controller
{
    public function index()
    {
        $pageTitle = "General Setting";
        $this->view('admin/setting/index', compact('pageTitle'));
    }

    public function store()
    {
        $request = new Request();
        
        $request->validate([
            'buzzlab_email_batch_prefix' => 'required',
            'buzzlab_sms_batch_prefix' => 'required'
        ]);

        update_option('buzzlab_email_batch_prefix', sanitize_text_field($request->buzzlab_email_batch_prefix));
        update_option('buzzlab_sms_batch_prefix', sanitize_text_field($request->buzzlab_sms_batch_prefix));

        $notify[] = ['success', 'General setting updated successfully'];
        buzz_set_notify($notify);
        buzz_back();
    }

    public function systemConfiguration()
    {
        $pageTitle = "System Configuration";
        return $this->view('admin/setting/configuration', compact('pageTitle'));
    }

    public function systemConfigurationStore()
    {
        $request = buzz_request();
        
        update_option('buzz_email_notification', $request->buzz_email_notification ? 1 : 0);
        update_option('buzz_sms_notification', $request->buzz_sms_notification ? 1 : 0);

        $notify[] = ['success', 'System configuration update successfully'];
        buzz_set_notify($notify);
        buzz_back();
    }

    public function logoIcon()
    {
        $pageTitle = 'Logo & Favicon';
        $this->view('admin/setting/logo_icon', compact('pageTitle'));
    }

    public function logoIconSubmit()
    {
        $request = new Request();
        $request->validate([
            'logo' => 'image|mimes:jpg,jpeg,png',
            'favicon' => 'image|mimes:png',
        ]);

        $path = BUZZLAB_ROOT . 'assets/global/images';
        $image = new Image();

        if ($request->hasFile('logo')) {
            try {
                if (!file_exists($path)) {
                    mkdir($path, 0755, true);
                }
                $image->make($request->logo['tmp_name'])->save($path . '/logo.png');
            } catch (\Exception $exp) {
                $notify[] = ['error', 'Couldn\'t upload the logo'];
                buzz_set_notify($notify);
                buzz_back();
            }
        }

        if ($request->hasFile('favicon')) {
            try {
                if (!file_exists($path)) {
                    mkdir($path, 0755, true);
                }
                $size = explode('x', buzz_file_size('favicon'));
                $image->make($request->favicon['tmp_name'])->resize($size[0], $size[1])->save($path . '/favicon.png');
            } catch (\Exception $exp) {
                $notify[] = ['error', 'Couldn\'t upload the favicon'];
                buzz_set_notify($notify);
                buzz_back();
            }
        }

        $notify[] = ['success', 'Logo & favicon updated successfully'];
        buzz_set_notify($notify);
        buzz_back();
    }
}
