<?php

namespace Buzzlab\Controllers\Admin;

use Buzzlab\BackOffice\Request;
use Buzzlab\Controllers\Controller;
use Buzzlab\Models\Contact;
use Buzzlab\Models\Group;
use Buzzlab\Models\GroupContact;

class GroupController extends Controller
{
    protected $pageTitle;



    public function emailGroup()
    {
        $this->pageTitle = 'Manage Email Groups';
        return $this->groupData(1);
    }

    public function smsGroup()
    {
        $this->pageTitle = 'Manage Email Groups';
        return $this->groupData(2);
    }

    public function banned()
    {
        $this->pageTitle = 'Manage Banned Groups';
        return $this->groupData(0);
    }
    public function groups()
    {
        $this->pageTitle = 'All Groups';
        return $this->groupData('all');
    }

    public function groupData($groupType)
    {
        global $table_prefix;
        $query = "select `" . $table_prefix . "buzz_groups`.*, (select count(*) from `" . $table_prefix . "buzz_contacts` inner join `" . $table_prefix . "buzz_group_contacts` on `" . $table_prefix . "buzz_contacts`.`id` = `" . $table_prefix . "buzz_group_contacts`.`contact_id` where `" . $table_prefix . "buzz_groups`.`id` = `" . $table_prefix . "buzz_group_contacts`.`group_id`) as `contact_count` from `" . $table_prefix . "buzz_groups`";
        
        $groups = Group::where('type', $groupType)->orderBy('id', 'desc')->selectRaw($query)->paginate(buzz_paginate());
        if ($groupType == 'all') {
            $groups = Group::orderBy('id', 'desc')->selectRaw($query)->paginate(buzz_paginate());
        }
        $pageTitle = $this->pageTitle;
        $this->view('admin/group/index', compact('pageTitle', 'groups', 'groupType'));
    }

    public function status()
    {
        $request = new Request();
        $group =  Group::find($request->id);
        if (!$group) {
            buzz_abort(404);
        }
        $group->status = $group->status ? 0 : 1;
        $group->save();
        $notify[] = ['success', 'Status updated successfully'];
        buzz_set_notify($notify);
        buzz_back();
    }

    public function store()
    {
        $request = new Request();
        $request->validate([
            'name' => 'required',
            'type' => 'required|in:1,2,0',   //1 = Email Group, 2 = SMS Group, 0 = banned
        ]);

        $existing =  Group::where('name', $request->name)->first();
        if ($existing) {
            $notify[] = ['error', 'Group already exist'];
            buzz_set_notify($notify);
            buzz_back();
        }
        $group       = new Group();
        $group->name = sanitize_text_field($request->name);
        $group->type = sanitize_text_field($request->type);
        $group->created_at   = current_time('mysql');
        $group->save();
        $notify[] = ['success', 'Group added successfully'];
        buzz_set_notify($notify);
        buzz_back();
    }

    public function update()
    {
        $request = new Request();
        $request->validate([
            'name' => 'required',
            'type' => 'required|in:1,2,0',   //1 = Email Group, 2 = SMS Group, 0 = banned
        ]);

        $group  = Group::findOrFail($request->id);

        $group->name   = sanitize_text_field($request->name);
        $group->updated_at   = current_time('mysql');
        $group->save();
        $notify[] = ['success', 'Group updated successfully'];
        buzz_set_notify($notify);
        buzz_back();
    }

    public function viewGroupContact()
    {
        $request = new Request();
        $group  = Group::findOrFail($request->id);
        $pageTitle = 'View Group: ' . $group->data->name;
        $contacts = GroupContact::where('group_id', $request->id)->orderBy('id', 'desc')->paginate(buzz_paginate());
        $this->view('admin/group/view_contact', compact('pageTitle', 'group', 'contacts'));
    }


    public function searchGroupContact()
    {
        $request = new Request;
        $type = $request->type;
        $contacts = Contact::where('status', 1)->where($type, '!=', null);
        // if ($request->group_id) {
        //     $contacts = $contacts->whereDoesNotHave(Group::class,GroupContact::class,'group_id','contact_id',' AND `group_id` = '.$request->group_id);
        // }
        $totalData=$contacts->count();
        $contacts = $contacts->paginate(buzz_paginate());
       
        if ($request->forSelect2) {
            $response = [];
            $response['data'] = $contacts->data;
            $response['pagination'] = count((array) $contacts->data);
            $response['total_data']=$totalData;
            wp_send_json($response);
        }
    }

    public function saveGroupContact()
    {
        $request  = new Request;
        $request->validate([
            'contacts' => 'required|array'
        ]);
        $groupType = $request->group_type == 'email' ? 1 : 2;
        $group = Group::where('id', $request->group_id)->where('type', $groupType)->first();
        if (!$group) {
            $notify[] = ['error', 'Group does not exist'];
            buzz_set_notify($notify);
            buzz_back();
        }

        foreach ($request->contacts as $contact) {

            $groupContact = GroupContact::where('group_id', $request->group_id)->where('contact_id', $contact)->first();
            if (!$groupContact) {
                $groupContact = new GroupContact();
                $groupContact->group_id  = $request->group_id;
                $groupContact->contact_id  = $contact;
                $groupContact->save();
            }
        }

        $notify[] = ['success', 'Group contact added  successfully'];
        buzz_set_notify($notify);
        buzz_back();
    }

    public function deleteGroupContact()
    {
        $request = new Request;
        GroupContact::where('contact_id', $request->id)->delete();
        $notify[] = ['success', 'Contact deleted from the group successfully'];
        buzz_set_notify($notify);
        buzz_back();
    }
}
