<?php

namespace Buzzlab\Controllers\Admin;

use Buzzlab\Controllers\Controller;
use Buzzlab\BackOffice\Request;
use Buzzlab\Models\Group;
use Buzzlab\Models\GroupContact;
use Buzzlab\Models\Batch;
use Buzzlab\Models\Contact;
use Buzzlab\BackOffice\Validator\Validator;
use Buzzlab\Models\SmsHistory;

class SmsController extends Controller
{
    public function history()
    {
        $pageTitle = 'SMS History';
        $request   = new Request();
        $query     = SmsHistory::orderBy('id', 'DESC');
        if ($request->batch_id) {
            $batch     = Batch::where('id', $request->batch_id)->first();
            $pageTitle = "SMS History For Batch: " . $batch->batch_id;
            $logs = $query->where('batch_id', $batch->id)->paginate(buzz_paginate());
        } elseif ($request->status == 1) {
            $logs      = $query->where('status', 1);
        } elseif ($request->status == 2) {
            $logs      = $query->where('status', 2);
        } elseif ($request->status == 9) {
            $logs      = $query->where('status', 9);
        }
        $logs = $query->paginate(buzz_paginate());

        $this->view('admin/sms/history', compact('pageTitle', 'logs'));
    }

    public function smsView()
    {
        $request   = new Request();
        $sms       = SmsHistory::findOrFail($request->id);
        $pageTitle = "SMS Details";
        $this->view('admin/sms/details', compact('pageTitle', 'sms'));
    }


    public function sendSmsForm()
    {
        $pageTitle = 'Send SMS';
        $groups    = Group::where('type', 2)->where('status', 1)->get();
        $this->view('admin/sms/send_form', compact('pageTitle', 'groups'));
    }

    public function merge()
    {
        $request = new Request();
        $validations = Validator::make([
            'file'       => 'file|size:3072|mimes:csv,xlsx,txt',
        ]);
        if (!empty($validations['errors'])) {
            wp_send_json([
                'success' => false,
                'errors'  => $validations['errors']
            ]);
            die;
        }
        $mobileFromFile = [];
        if ($request->hasFile('file')) {
            try {
                $fileRead = buzz_import_file_reader($request->file, ['mobile'], [], false);
                $mobileReadFromFile = $fileRead->getReadData();

                if (count($mobileReadFromFile)) {
                    foreach ($mobileReadFromFile as $mobile) {
                        $mobileFromFile[] = @$mobile[0];
                    }
                }
            } catch (\Exception $ex) {
                return wp_send_json([
                    'success' => false,
                    'errors'  => [$ex->getMessage()]

                ]);
            }
        }
        $contactId        = $request->contact_id ?? [];
        $mobileFromContact = Contact::whereIn('id', $contactId)->get();
        $mobileContacts = [];
        foreach ($mobileFromContact as $contact) {
            $mobileContacts[] = $contact->mobile;
        }
        $groupId          = $request->group_id ?? [];
        $mobileFromGroup   = GroupContact::whereIn('group_id', $groupId)->get();
        foreach ($mobileFromGroup as $group) {
            $contact = Contact::where('status', 1)->findOrFail($group->contact_id);
            $mobileContacts[] = $contact->mobile;
        }
        $mobileContacts = array_merge($mobileContacts, $mobileFromFile);
        $mobileContacts = array_unique($mobileContacts);
        if (count($mobileContacts) <= 0) {
            return wp_send_json([
                'success'                    => false,
                'errors'                     => ["At least one mobile number required"]
            ]);
            die;
        }
        buzz_session()->put('MOBILE_NUMBER_FOR_SEND', $mobileContacts);
        return wp_send_json([
            'success' => true,
            'mobiles' => $mobileContacts
        ]);
    }

    public function send()
    {
        $request = new Request();
        $validations = Validator::make([
            'will_be_sent' => 'required|in:1,2',
            'message'      => 'required'
        ]);
        if (!empty($validations['errors'])) {
            wp_send_json([
                'success' => false,
                'errors'  => $validations['errors']
            ]);
            die;
        }
        $batch = Batch::where('batch_id', $request->batch_id)->first();
        if (!$batch) {
            $batch                      = new Batch();
            $batch->type                = 2;
            $batch->batch_id            = $request->batch_id;
            $batch->total               = count(buzz_session()->get('MOBILE_NUMBER_FOR_SEND'));
            $batch->schedule            = buzz_date()->now();
            $batch->sender              = get_option('buzz_sms_config')['name'];
        }
        $contact     = Contact::where('mobile', $request->mobile)->first();
        $smsHistory             = new SmsHistory();
        $smsHistory->contact_id = $contact ? $contact->id : 0;
        $smsHistory->mobile     = $request->mobile;
        $smsHistory->message    = $request->message;
        $smsHistory->schedule   = buzz_date()->parse($request->date)->toDateTime();
        $smsHistory->sender     = get_option('buzz_sms_config')['name'];
        if ($request->will_be_sent == 1) {
            $user = [
                'user_email' => $smsHistory->mobile,
                'display_name'   => $smsHistory->mobile,
                'user_login' => $smsHistory->mobile,
            ];
            buzz_notify($user, 'DEFAULT', [
                'subject'               => 'blah',
                'message'               => $smsHistory->message
            ], ['sms'], false);
            if (buzz_session()->has('sms_error')) {
                $smsHistory->status   = 9;
                $smsHistory->fail_reason = buzz_session()->get('sms_error');
                buzz_session()->forget('sms_error');
                $batch->total_fail++;
            } else {
                $smsHistory->status  = 1;
                $batch->total_success++;
            }
            $smsHistory->sent_time   = buzz_date()->now();
            $batch->status              = 1;
        }
        $batch->save();
        $smsHistory->batch_id   = $batch->id;
        $smsHistory->save();
        wp_send_json([
            'success' => true
        ]);
    }
}
