<?php

use Buzzlab\BackOffice\Abort;
use Buzzlab\Lib\FileManager;
use Buzzlab\BackOffice\Request;
use Buzzlab\BackOffice\Session;
use Buzzlab\BackOffice\System;
use Buzzlab\Lib\Captcha;
use Buzzlab\Lib\ClientInfo;
use Buzzlab\Lib\ImportFileReader;
use Buzzlab\Lib\ViserDate;
use Buzzlab\Models\Batch;
use Buzzlab\Models\Contact;
use Buzzlab\Models\Form;
use Buzzlab\Models\SupportTicket;
use Buzzlab\Notify\Notify;

if (!function_exists('buzz_system_details')) {
    function buzz_system_details()
    {
        $system['prefix'] = 'wp_';
        $system['real_name'] = 'buzzlab';
        $system['name'] = $system['prefix'] . 'buzzlab';
        $system['version'] = '1.1';
        $system['build_version'] = '1.0';
        return $system;
    }
}

if (!function_exists('buzz_system_instance')) {
    function buzz_system_instance()
    {
        return System::getInstance();
    }
}

if (!function_exists('dd')) {
    function dd(...$data)
    {
        foreach ($data as $item) {
            echo "<pre style='background: #001140;color: #00ff4e;padding: 20px;'>";
            print_r($item);
            echo "</pre>";
        }
        exit;
    }
}

if (!function_exists('dump')) {
    function dump(...$data)
    {
        foreach ($data as $item) {
            echo "<pre style='background: #001140;color: #00ff4e;padding: 20px;'>";
            print_r($item);
            echo "</pre>";
        }
    }
}

if (!function_exists('buzz_layout')) {
    function buzz_layout($buzz_layout)
    {
        global $systemLayout;
        $systemLayout = $buzz_layout;
    }
}

if (!function_exists('buzz_route')) {
    function buzz_route($routeName)
    {
        $route = buzz_system_instance()->route($routeName);
        return buzz_to_object($route);
    }
}

if (!function_exists('buzz_to_object')) {
    function buzz_to_object($args)
    {
        if (is_array($args)) {
            return (object) array_map(__FUNCTION__, $args);
        } else {
            return $args;
        }
    }
}

if (!function_exists('buzz_to_array')) {
    function buzz_to_array($args)
    {
        if (is_object($args)) {
            $args = get_object_vars($args);
        }

        if (is_array($args)) {
            return array_map(__FUNCTION__, $args);
        } else {
            return $args;
        }
    }
}


if (!function_exists('buzz_redirect')) {
    function buzz_redirect($url)
    {
        wp_redirect($url);
        exit;
    }
}

if (!function_exists('buzz_key_to_title')) {
    function buzz_key_to_title($text)
    {
        return ucfirst(preg_replace("/[^A-Za-z0-9 ]/", ' ', $text));
    }
}

if (!function_exists('buzz_request')) {
    function buzz_request()
    {
        return new Request();
    }
}

if (!function_exists('buzz_remove_session')) {
    function buzz_remove_session($key)
    {
        unset($_SESSION[$key]);
    }
}

if (!function_exists('buzz_session')) {
    function buzz_session()
    {
        return new Session();
    }
}

if (!function_exists('buzz_back')) {
    function buzz_back()
    {
        if (isset($_SERVER['HTTP_REFERER'])) {
            $url = $_SERVER['HTTP_REFERER'];
        } else {
            $url = home_url();
        }
        buzz_redirect($url);
    }
}

if (!function_exists('buzz_old')) {
    function buzz_old($key)
    {
        return @buzz_session()->get('old_input_value_' . $key);
    }
}

if (!function_exists('buzz_abort')) {
    function buzz_abort($code = 404, $message = null)
    {
        $abort = new Abort($code, $message);
        $abort->buzz_abort();
    }
}

if (!function_exists('buzz_query_to_url')) {
    function buzz_query_to_url($arr)
    {
        return esc_url(add_query_arg($arr, $_SERVER['REQUEST_URI']));
    }
}

if (!function_exists('buzz_set_notify')) {
    function buzz_set_notify($data)
    {
        buzz_session()->flash('notify', $data);
    }
}

if (!function_exists('buzz_include')) {
    function buzz_include($view, $data = [])
    {
        extract($data);
        include BUZZLAB_ROOT . 'views/' . $view . '.php';
    }
}

if (!function_exists('buzz_ip_info')) {
    function buzz_ip_info()
    {
        $ipInfo = ClientInfo::ipInfo();
        return $ipInfo;
    }
}

if (!function_exists('buzz_real_ip')) {
    function buzz_real_ip()
    {
        $ip = $_SERVER["REMOTE_ADDR"];
        //Deep detect ip
        if (filter_var(@$_SERVER['HTTP_FORWARDED'], FILTER_VALIDATE_IP)) {
            $ip = $_SERVER['HTTP_FORWARDED'];
        }
        if (filter_var(@$_SERVER['HTTP_FORWARDED_FOR'], FILTER_VALIDATE_IP)) {
            $ip = $_SERVER['HTTP_FORWARDED_FOR'];
        }
        if (filter_var(@$_SERVER['HTTP_X_FORWARDED_FOR'], FILTER_VALIDATE_IP)) {
            $ip = $_SERVER['HTTP_X_FORWARDED_FOR'];
        }
        if (filter_var(@$_SERVER['HTTP_CLIENT_IP'], FILTER_VALIDATE_IP)) {
            $ip = $_SERVER['HTTP_CLIENT_IP'];
        }
        if (filter_var(@$_SERVER['HTTP_X_REAL_IP'], FILTER_VALIDATE_IP)) {
            $ip = $_SERVER['HTTP_X_REAL_IP'];
        }
        if (filter_var(@$_SERVER['HTTP_CF_CONNECTING_IP'], FILTER_VALIDATE_IP)) {
            $ip = $_SERVER['HTTP_CF_CONNECTING_IP'];
        }
        if ($ip == '::1') {
            $ip = '127.0.0.1';
        }

        return $ip;
    }
}

if (!function_exists('buzz_route_link')) {
    function buzz_route_link($name,$isEscape = true)
    {
        $route = buzz_to_array(buzz_route($name));
        if (array_key_exists('query_string', $route)) {
            $link = menu_page_url(BUZZLAB_PLUGIN_NAME, false) . '&module=' . $route['query_string'];
        } else {
            $link = home_url($route['uri']);
        }
        if ($isEscape) {
            return esc_url($link);
        }
        return $link;
    }
}

if (!function_exists('buzz_menu_active')) {
    function buzz_menu_active($routeName, $type = null, $param = null, $dashboard = false)
    {
        if ($type == 3) $class = 'side-menu--open';
        elseif ($type == 2) $class = 'sidebar-submenu__open';
        else $class = 'active';
        if (!is_array($routeName)) {
            $routeName = [$routeName];
        }
        foreach ($routeName as $key => $value) {
            $route = buzz_route($value);
            $queryString = $route->query_string;
            if (isset(buzz_request()->module) && buzz_request()->module == $queryString) {
                echo sanitize_html_class($class);
            }
            if (isset(buzz_request()->page) && buzz_request()->page == BUZZLAB_PLUGIN_NAME && !isset(buzz_request()->module) && $dashboard) {
                echo sanitize_html_class($class);
            }
        }
    }
}

if (!function_exists('buzz_nonce_field')) {
    function buzz_nonce_field($routeName, $isPrint = true)
    {
        $route = buzz_to_array(buzz_route($routeName));
        if (array_key_exists('query_string', $route)) {
            $nonceName = $route['query_string'];
        } else {
            $nonceName = $route['uri'];
        }
        if ($isPrint) {
            echo '<input type="hidden" name="nonce" value="' . wp_create_nonce($nonceName) . '">';
        } else {
            return '<input type="hidden" name="nonce" value="' . wp_create_nonce($nonceName) . '">';
        }
    }
}

if (!function_exists('buzz_current_route')) {
    function buzz_current_route()
    {
        if (isset(buzz_request()->page)) {
            if (isset(buzz_request()->module)) {
                return buzz_request()->module;
            } else {
                return buzz_request()->page;
            }
        } else {
            return home_url(get_query_var('buzz_page'));
        }
    }
}

if (!function_exists('buzz_assets')) {
    function buzz_assets($path)
    {
        $path = BUZZLAB_PLUGIN_NAME . '/assets/' . $path;
        $path = str_replace('//', '/', $path);
        return plugins_url($path);
    }
}

if (!function_exists('buzz_get_image')) {
    function buzz_get_image($image)
    {
        $clean = '';
        if (file_exists(BUZZLAB_ROOT . 'assets/' . $image) && is_file(BUZZLAB_ROOT . 'assets/' . $image)) {
            return buzz_assets($image) . $clean;
        }
        return buzz_assets('images/default.png');
    }
}

if (!function_exists('buzz_file_uploader')) {
    function buzz_file_uploader($file, $location, $size = null, $old = null, $thumb = null)
    {
        $fileManager = new FileManager($file);
        $fileManager->path = $location;
        $fileManager->size = $size;
        $fileManager->old = $old;
        $fileManager->thumb = $thumb;
        $fileManager->upload();
        return $fileManager->filename;
    }
}

if (!function_exists('buzz_file_manager')) {
    function buzz_file_manager()
    {
        return new FileManager();
    }
}


if (!function_exists('buzz_file_path')) {
    function buzz_file_path($key)
    {
        $dir = wp_upload_dir()['baseurl'];
        if (!empty($_FILES)) {
            $dir = wp_upload_dir()['basedir'];
        }
        return $dir . '/buzz_files/' . buzz_file_manager()->$key()->path;
    }
}

if (!function_exists('buzz_file_size')) {
    function buzz_file_size($key)
    {
        return buzz_file_manager()->$key()->size;
    }
}

if (!function_exists('buzz_file_ext')) {
    function buzz_file_ext($key)
    {
        return buzz_file_manager()->$key()->extensions;
    }
}

if (!function_exists('buzz_push_breadcrumb')) {
    function buzz_push_breadcrumb($html)
    {
        add_action('buzz_breadcrumb_plugins', function () use ($html) {
            echo $html;
        });
    }
}

if (!function_exists('buzz_check_empty')) {
    function buzz_check_empty($data)
    {
        if (is_object($data)) {
            $data = (array) $data;
        }
        return empty($data);
    }
}

if (!function_exists('buzz_allowed_html')) {
    function buzz_allowed_html()
    {
        $arr = array(
            'span' => array(
                'class' => []
            ),
            'br' => [],
            'a' => array(
                'href' => true,
                'class' => [],
            ),
            'em' => array(),
            'b' => array(),
            'bold' => array(),
            'blockquote' => array(),
            'p' => array(),
            'li' => array(
                'class' => [],
                'id' => []
            ),
            'ol' => array(),
            'strong' => array(),
            'ul' => array(
                'id' => [],
                'class' => [], 1
            ),
            'div' => array(
                'id' => [],
                'class' => [], 1
            ),
            'img' => array(
                'src' => true
            ),
            'table' => [],
            'tr' => [],
            'td' => [],
            'i' => array(
                'class' => []
            )
        );
        return $arr;
    }
}

if (!function_exists('buzz_currency')) {
    function buzz_currency($type = 'text')
    {
        return get_option("buzz_cur_$type");
    }
}

if (!function_exists('buzz_get_amount')) {
    function buzz_get_amount($amount, $length = 2)
    {
        $amount = round($amount, $length);
        return $amount + 0;
    }
}

if (!function_exists('buzz_show_amount')) {
    function buzz_show_amount($amount, $decimal = 2, $separate = true, $exceptZeros = false)
    {
        $separator = '';
        if ($separate) {
            $separator = ',';
        }
        $printAmount = number_format($amount, $decimal, '.', $separator);
        if ($exceptZeros) {
            $exp = explode('.', $printAmount);
            if ($exp[1] * 1 == 0) {
                $printAmount = $exp[0];
            } else {
                $printAmount = rtrim($printAmount, '0');
            }
        }
        return $printAmount;
    }
}

if (!function_exists('buzz_global_notify_short_codes')) {
    function buzz_global_notify_short_codes()
    {
        $data['site_name'] = 'Name of your site';
        return $data;
    }
}




if (!function_exists('buzz_show_date_time')) {
    function buzz_show_date_time($date, $format = 'Y-m-d h:i A')
    {
        return buzz_date()->parse($date)->toDateTime($format);
    }
}

if (!function_exists('buzz_str_limit')) {
    function buzz_str_limit($str, $length = 100, $end = '...')
    {

        if (mb_strwidth($str, 'UTF-8') <= $length) {
            return $str;
        }

        return rtrim(mb_strimwidth($str, 0, $length, '', 'UTF-8')).$end;
    }
}

if (!function_exists('buzz_diff_for_humans')) :
    function buzz_diff_for_humans($date, $to = '')
    {
        if (empty($to)) {
            $to = current_time('timestamp');
        }
        $from = strtotime($date);
        return human_time_diff($from, $to) . " ago";
    }
endif;

if (!function_exists('buzz_notify')) {
    function buzz_notify($user, $templateName, $shortCodes = null, $sendVia = null, $createLog = true)
    {
        $globalShortCodes = [
            'site_name' => get_bloginfo('name')
        ];

        if (gettype($user) == 'array') {
            $user = (object) $user;
        }

        $userInfo = [
            'email' => $user->user_email,
            'fullname' => $user->display_name
        ];

        $userInfo = buzz_to_object($userInfo);

        $shortCodes = array_merge($shortCodes ?? [], $globalShortCodes);
        $notify = new Notify($sendVia);
        $notify->templateName = $templateName;
        $notify->shortCodes = $shortCodes;
        $notify->user = $userInfo;
        $notify->createLog = $createLog;
        $notify->send();
    }
}

if (!function_exists('buzz_auth')) {
    function buzz_auth()
    {
        include_once(ABSPATH . 'wp-includes/pluggable.php');
        if (is_user_logged_in()) {
            return (object)[
                'user' => wp_get_current_user(),
                'meta' => get_user_meta(wp_get_current_user()->ID)
            ];
        }
        return false;
    }
}

if (!function_exists('buzz_trx')) {
    function buzz_trx($length = 12)
    {
        $characters = 'ABCDEFGHJKMNOPQRSTUVWXYZ123456789';
        $charactersLength = strlen($characters);
        $randomString = '';
        for ($i = 0; $i < $length; $i++) {
            $randomString .= $characters[rand(0, $charactersLength - 1)];
        }
        return $randomString;
    }
}

if (!function_exists('buzz_asset')) {
    function buzz_asset($path)
    {
        $path = BUZZLAB_PLUGIN_NAME . '/assets/' . $path;
        $path = str_replace('//', '/', $path);
        return plugins_url($path);
    }
}

if (!function_exists('buzz_balance')) {
    function buzz_balance($userId)
    {
        $balance = get_user_meta($userId, 'buzz_balance', true);
        if ($balance > 0) {
            return buzz_get_amount($balance);
        } else {
            return 0;
        }
    }
}

if (!function_exists('buzz_get_form')) {
    function buzz_get_form($formId)
    {
        $form = Form::find($formId);
        $formData = [];
        if ($form) {
            $formData = maybe_unserialize($form->form_data);
        }
        extract($formData);
        include BUZZLAB_ROOT . 'views/form/form.php';
    }
}

if (!function_exists('buzz_title_to_key')) {
    function buzz_title_to_key($text)
    {
        return strtolower(str_replace(' ', '_', $text));
    }
}

if (!function_exists('buzz_encrypt')) {
    function buzz_encrypt($string)
    {
        return base64_encode($string);
    }
}

if (!function_exists('buzz_decrypt')) {
    function buzz_decrypt($string)
    {
        return base64_decode($string);
    }
}

if (!function_exists('buzz_crypto_qr')) {
    function buzz_crypto_qr($wallet)
    {
        return "https://chart.googleapis.com/chart?chs=300x300&cht=qr&chl=$wallet&choe=UTF-8";
    }
}


if (!function_exists('buzz_paginate')) {
    function buzz_paginate($num = 20)
    {
        return intval($num);
    }
}


if (!function_exists('buzz_date')) {
    function buzz_date()
    {
        return new ViserDate();
    }
}

if (!function_exists('buzz_batch_id')) {
    function buzz_batch_id($batchFor = 1)  //1=Email,2=SMS
    {
        $batchPrefix = $batchFor == 1 ? get_option('buzzlab_email_batch_prefix') : get_option('buzzlab_sms_batch_prefix');
        $batchId = $batchPrefix . '-' . ((Batch::max('id') ?? 0) + 1);
        return $batchId;
    }
}

if (!function_exists('buzz_import_file_reader')) {
    function buzz_import_file_reader($file, $columns, $uniqueColumns = [], $dataInsert = true, $modelClass = Contact::class)
    {
        $fileRead                  = new ImportFileReader($file, $modelClass);
        $fileRead->columns         = $columns;
        $fileRead->uniqueColumns   = $uniqueColumns;
        $fileRead->dataInsertMode  = $dataInsert;
        $fileRead->readFile();
    
        return $fileRead;
    }
}