<?php

namespace Buzzlab\Hook;

use Buzzlab\Controllers\ActivationController;
use Buzzlab\Controllers\Admin\ContactController;
use Buzzlab\Controllers\Admin\GroupController;
use Buzzlab\Controllers\Admin\EmailController;
use Buzzlab\Controllers\Admin\SmsController;
use Buzzlab\Controllers\CronController;
use Buzzlab\Hook\AdminMenu;
use Buzzlab\Lib\VerifiedPlugin;

class Hook
{

    public function init()
    {
        add_action('admin_menu', [new AdminMenu, 'menuSetting']);


        add_action('init', [new ExecuteRouter, 'execute']);
        add_filter('template_include', [new ExecuteRouter, 'includeTemplate'], 1000, 1);
        add_action('query_vars', [new ExecuteRouter, 'setQueryVar']);

        $loadAssets = new LoadAssets('admin');
        add_action('admin_enqueue_scripts', [$loadAssets, 'enqueueScripts']);
        add_action('admin_enqueue_scripts', [$loadAssets, 'enqueueStyles']);

        add_action('admin_enqueue_scripts', function(){
            wp_enqueue_style( 'global_admin', esc_url(plugin_dir_url('/') .BUZZLAB_PLUGIN_NAME.  "/assets/admin/css/global_admin.css"), array(), BUZZLAB_PLUGIN_VERSION, 'all' );
        });

        $loadAssets = new LoadAssets('public');
        add_action('wp_enqueue_scripts', [$loadAssets, 'enqueueScripts']);
        add_action('wp_enqueue_scripts', [$loadAssets, 'enqueueStyles']);

        // $this->authHooks();

        add_action('plugin_loaded', function () {
            load_plugin_textdomain(
                BUZZLAB_PLUGIN_NAME,
                false,
                dirname(dirname(dirname(plugin_basename(__FILE__)))) . '/languages'
            );
        });

        add_action('wp_dashboard_setup', function () {
            $widget = new Widget();
            $widget->loadWidget();
        });

        add_filter('admin_body_class', function ($classes) {
            if (isset($_GET['page']) && $_GET['page'] == BUZZLAB_PLUGIN_NAME) {
                $classes .= ' vl-admin';
            }
            return $classes;
        });

        add_action('init', function () {
            ob_start();
        });

        add_action('wp_ajax_group_contact_search', function () {
            $groupController = new GroupController;
            $groupController->searchGroupContact();
        });

        add_action('wp_ajax_merge_contact', function () {
            $emailController = new EmailController;
            $emailController->merge();
        });

        add_action('wp_ajax_send_email_to_contacts', function () {
            $emailController = new EmailController;
            $emailController->send();
        });

        add_action('wp_ajax_merge_mobile_contact', function () {
            $smsController = new SmsController;
            $smsController->merge();
        });

        add_action('wp_ajax_send_sms_to_contacts', function () {
            $smsController = new SmsController;
            $smsController->send();
        });

        add_action('wp_ajax_contact_import', function () {
            $contactController = new ContactController;
            $contactController->importContact();
        });


        //corn-job
        add_filter('cron_schedules', function(){
            $prune_duration = 60;
            $schedules['buzzlab_prune'] = array(
                'interval' => $prune_duration,
                'display'  => 'Prune Duration'
            );
            
            return $schedules;
        });
        if (!wp_next_scheduled('buzzlab_cron_action')) {
            wp_schedule_event(time(), 'buzzlab_prune', 'buzzlab_cron_action');
        }
        add_action('buzzlab_cron_action', [new CronController,'sentScheduleEmail']);
        add_action('buzzlab_cron_action', [new CronController,'sentScheduleSms']);


        // add_action('admin_init',[new Demo, 'protectPost']);
        // add_filter('plugin_action_links',[new Demo, 'disablePluginDeactivation'], 10, 4 );


        add_action('admin_init',function(){
            if (!VerifiedPlugin::check()) {
                add_action('admin_notices', function(){
                    $activationUrl = buzz_route_link('plugin.activation');
                    echo "<div class='notice notice-error is-dismissible'><p><strong>".__('Please',BUZZLAB_PLUGIN_NAME)." <a href='$activationUrl'>".__('activate',BUZZLAB_PLUGIN_NAME)."</a> ".__('the '.ucfirst(BUZZLAB_PLUGIN_NAME).' Plugin',BUZZLAB_PLUGIN_NAME)."</strong></p></div>";
                });
            } 
        });

        add_action('wp_ajax_active-plugin',function(){
            $controller = new ActivationController;
            $controller->activationSubmit();
        });
    }

    public function authHooks()
    {
        $authorization = new Authorization;
        add_action('after_setup_theme', [$authorization, 'removeAdminBar']);
        add_action('admin_init', [$authorization, 'redirectHome'], 1);
        add_action('login_init', [$authorization, 'restrictWpLogin'], 1);
        add_filter('login_url', [$authorization, 'redirectLogin'], 10, 2);
        add_action('wp_login_failed', [$authorization, 'authFailed']);
        add_filter('authenticate', [$authorization, 'authenticate'], 20, 3);
        add_filter('wp_authenticate_user', [$authorization, 'verifyUser'], 1);
        add_action('edit_user_profile', [$authorization, 'userProfile']);
        add_action('edit_user_profile_update', [$authorization, 'updateUserProfile']);
    }
}
