<?php
buzz_layout('admin/layouts/master');

$emailShow = $contactType == 'all' || $contactType == 'email' ? true : false;
$mobileShow = $contactType == 'all' || $contactType == 'mobile' ? true : false;
?>

<div class="row">
    <div class="col-lg-12">
        <div class="card mb-4">
            <div class="card-body">

                <!-- Filter Form -->
                <form method="GET" action="#">
                    <input type="hidden" name="page" value="<?php echo BUZZLAB_PLUGIN_NAME ?>">
                    <input type="hidden" name="module" value="<?php echo $contactType ?>_contact">
                    <div class="align-items-center justify-content-end d-flex flex-wrap gap-2">
                        <div class="flex-fill">
                            <label><?php esc_html_e('Name', BUZZLAB_PLUGIN_NAME); ?></label>
                            <input type="name" autocomplete="off" name="name" value="<?php echo buzz_request()->name ?>" placeholder="<?php esc_attr_e('Search with name', BUZZLAB_PLUGIN_NAME); ?>" class="form-control">
                        </div>
                        <?php if ($emailShow) : ?>
                            <div class="flex-fill">
                                <label><?php esc_html_e('Email', BUZZLAB_PLUGIN_NAME); ?></label>
                                <input type="text" autocomplete="off" name="email" value="<?php echo buzz_request()->email ?>" placeholder="<?php esc_attr_e('Search with email', BUZZLAB_PLUGIN_NAME); ?>" class="form-control">
                            </div>
                        <?php endif ?>

                        <?php if ($mobileShow) : ?>
                            <div class="flex-fill">
                                <label><?php esc_html_e('Mobile', BUZZLAB_PLUGIN_NAME); ?></label>
                                <input type="text" autocomplete="off" name="mobile" value="<?php echo buzz_request()->mobile ?>" placeholder="<?php esc_attr_e('Search with mobile', BUZZLAB_PLUGIN_NAME); ?>" class="form-control">
                            </div>
                        <?php endif ?>

                        <div class="flex-fill">
                            <label><?php esc_html_e('Status', BUZZLAB_PLUGIN_NAME); ?></label>
                            <select class="form-control" name="status">
                                <option value=""><?php esc_html_e('Select One', BUZZLAB_PLUGIN_NAME); ?></option>
                                <option value="1" <?php selected(buzz_request()->status == 1) ?>><?php esc_html_e('Active', BUZZLAB_PLUGIN_NAME); ?></option>
                                <option value="0" <?php selected(buzz_request()->status != null && buzz_request()->status == 0) ?>><?php esc_html_e('Inactive', BUZZLAB_PLUGIN_NAME); ?></option>
                            </select>
                        </div>

                        <div class="flex-fill">
                            <button class="btn btn--primary w-100 h-45 mt-4" type="submit">
                                <i class="fas fa-filter"></i><?php esc_html_e('Filter', BUZZLAB_PLUGIN_NAME); ?>
                            </button>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <div class="col-12">
        <div class="card b-radius--10">
            <div class="card-body p-0">
                <div class="table-responsive--md table-responsive">
                    <table class="table--light style--two table">
                        <thead>
                            <tr>
                                <th><?php esc_html_e('Name', BUZZLAB_PLUGIN_NAME) ?></th>

                                <?php if ($emailShow) : ?>
                                    <th><?php esc_html_e('Email', BUZZLAB_PLUGIN_NAME) ?></th>
                                <?php endif ?>

                                <?php if ($mobileShow) : ?>
                                    <th><?php esc_html_e('Mobile', BUZZLAB_PLUGIN_NAME) ?></th>
                                <?php endif ?>

                                <th><?php esc_html_e('Status', BUZZLAB_PLUGIN_NAME) ?></th>
                                <th><?php esc_html_e('Action', BUZZLAB_PLUGIN_NAME) ?></th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($contacts->data as $contact) { ?>
                                <tr>
                                    <td> <?php esc_html_e($contact->name) ?></td>
                                    <?php if ($emailShow) : ?>
                                        <td><?php esc_html_e($contact->email) ?></td>
                                    <?php endif ?>
                                    <?php if ($mobileShow) : ?>
                                        <td><?php esc_html_e($contact->mobile) ?></td>
                                    <?php endif ?>
                                    <td>
                                        <?php
                                        if ($contact->status) {
                                            echo '<span class="text--small badge badge--success">' . esc_html("Active", BUZZLAB_PLUGIN_NAME) . '</span>';
                                        } else {
                                            echo '<span class="text--small badge badge--danger">' . esc_html("Inactive", BUZZLAB_PLUGIN_NAME) . '</span>';
                                        } ?>
                                    </td>
                                    <td>
                                        <div class="button--group">

                                            <button type="button" data-contact="<?php esc_attr_e(json_encode($contact)); ?>" class="btn btn-sm btn-outline--primary editBtn">
                                                <i class="la la-pencil"></i> <?php esc_html_e('Edit', BUZZLAB_PLUGIN_NAME); ?>
                                            </button>

                                            <?php if ($contact->status == 0) { ?>
                                                <button class="btn btn-sm btn-outline--success ms-1 confirmationBtn" data-question="<?php esc_attr_e('Are you sure to active this contact?', BUZZLAB_PLUGIN_NAME); ?>" data-action="<?php echo buzz_route_link('admin.contact.status'); ?>&amp;id=<?php echo intval($contact->id); ?>">
                                                    <i class="la la-eye"></i> <?php esc_html_e('Active', BUZZLAB_PLUGIN_NAME); ?>
                                                </button>
                                            <?php } else { ?>
                                                <button class="btn btn-sm btn-outline--danger ms-1 confirmationBtn" data-question="<?php esc_attr_e('Are you sure to inactive this contact?', BUZZLAB_PLUGIN_NAME); ?>" data-action="<?php echo buzz_route_link('admin.contact.status'); ?>&amp;id=<?php echo intval($contact->id); ?>">
                                                    <i class="la la-eye-slash"></i> <?php esc_html_e('Inactive', BUZZLAB_PLUGIN_NAME); ?>
                                                </button>
                                            <?php } ?>
                                        </div>
                                    </td>
                                </tr>
                            <?php } ?>
                            
                            <?php if (buzz_check_empty($contacts->data)) { ?>
                                <tr>
                                    <td colspan="6" class="text-center"><?php esc_html_e('Data Not Found', BUZZLAB_PLUGIN_NAME); ?></td>
                                </tr>
                            <?php } ?>
                        </tbody>
                    </table>
                </div>
            </div>
            <?php if (@$contacts->links) { ?>
                <div class="card-footer">
                    <?php echo wp_kses($contacts->links, buzz_allowed_html()); ?>
                </div>
            <?php } ?>
        </div>
    </div>
</div>


<!-- Contact Add Modal -->
<div class="modal fade" id="addModal">
    <div class="modal-dialog modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h4 class="modal-title"><?php esc_html_e('Add New Contact', BUZZLAB_PLUGIN_NAME) ?></h4>
                <button type="button" class="close" data-bs-dismiss="modal" aria-label="Close">
                    <i class="la la-times" aria-hidden="true"></i>
                </button>
            </div>
            <form method="POST" action="<?php echo buzz_route_link('admin.contact.store') ?>">
                <?php buzz_nonce_field('admin.contact.store'); ?>
                <input type="hidden" name="contact_type" value="<?php esc_attr_e($contactType, BUZZLAB_PLUGIN_NAME); ?>">
                <div class="modal-body">
                    <div class="form-group">
                        <label><?php esc_html_e('Name', BUZZLAB_PLUGIN_NAME); ?></label>
                        <input type="text" class="form-control" name="name" value="<?php echo esc_attr(buzz_old('name')); ?>">
                    </div>

                    <?php if ($emailShow) : ?>
                        <div class="form-group">
                            <label class="required"><?php esc_html_e('Email', BUZZLAB_PLUGIN_NAME); ?></label>
                            <input type="email" class="form-control" name="email" value="<?php echo esc_attr(buzz_old('email')); ?>" required>
                        </div>
                    <?php endif ?>

                    <?php if ($mobileShow) : ?>
                        <div class="form-group">
                            <label class="required"><?php esc_html_e('Mobile', BUZZLAB_PLUGIN_NAME); ?></label>
                            <input type="tel" class="form-control" name="mobile" value="<?php echo esc_attr(buzz_old('mobile
                            ')); ?>" required>
                        </div>
                    <?php endif ?>
                </div>
                <div class="modal-footer">
                    <button type="submit" class="btn btn--primary w-100 h-45" id="btn-save"><?php esc_html_e('Submit', BUZZLAB_PLUGIN_NAME); ?></button>
                </div>
            </form>
        </div>
    </div>
</div>

<!-- Contact Update Modal -->
<div class="modal fade" id="editModal">
    <div class="modal-dialog modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h4 class="modal-title"><?php esc_html_e('Edit Contact', BUZZLAB_PLUGIN_NAME) ?></h4>
                <button type="button" class="close" data-bs-dismiss="modal" aria-label="Close">
                    <i class="la la-times" aria-hidden="true"></i>
                </button>
            </div>
            <form method="POST" action="<?php echo buzz_route_link('admin.contact.update'); ?>" id="form">
                <?php buzz_nonce_field('admin.contact.update'); ?>

                <div class="modal-body">
                    <div class="form-group">
                        <label><?php esc_html_e('Name', BUZZLAB_PLUGIN_NAME); ?></label>
                        <input type="hidden" name="contact_type" value=" <?php esc_attr_e($contactType); ?>">
                        <input type="text" class="form-control name" name="name" value="<?php echo esc_attr(buzz_old('name')); ?>">
                    </div>

                    <?php if ($emailShow) : ?>
                        <div class="form-group">
                            <label class="required"><?php esc_html_e('Email', BUZZLAB_PLUGIN_NAME); ?></label>
                            <input type="email" class="form-control email" name="email" value="<?php echo esc_attr(buzz_old('email')); ?>" required>
                        </div>
                    <?php endif ?>

                    <?php if ($mobileShow) : ?>
                        <div class="form-group">
                            <label class="required"><?php esc_html_e('Mobile', BUZZLAB_PLUGIN_NAME); ?></label>
                            <input type="tel" class="form-control mobile" name="mobile" value="<?php echo esc_attr(buzz_old('mobile')); ?>" required>
                        </div>
                    <?php endif ?>
                </div>
                <div class="modal-footer">
                    <input type="hidden" class="contact_id" name="id">
                    <button type="submit" class="btn btn--primary w-100 h-45" id="btn-save"><?php esc_html_e('Submit', BUZZLAB_PLUGIN_NAME); ?></button>
                </div>
            </form>
        </div>
    </div>
</div>




<div class="modal fade" id="importModal" tabindex="-1" role="dialog">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-header">
                <h4 class="modal-title"><?php esc_html_e('Import Contact', BUZZLAB_PLUGIN_NAME); ?></h4>
                <button type="button" class="close" data-bs-dismiss="modal" aria-label="Close">
                    <i class="la la-times" aria-hidden="true"></i>
                </button>
            </div>
            <form method="post" action="" id="importForm" enctype="multipart/form-data">
                <input type="hidden" name="contact_type" value="<?php echo $contactType ?>">
                <div class="modal-body">
                    <div class="form-group">
                        <div class="alert alert-warning p-3" role="alert">
                            <p>
                                <?php esc_html_e('The file you wish to upload has to be formatted as we provided template files.Any changes to these files will be considered as an invalid file format. Download links are provided below.', BUZZLAB_PLUGIN_NAME); ?>
                            </p>
                        </div>
                    </div>
                    <div class="form-group">
                        <label class="fw-bold required"><?php esc_html_e('Select File', BUZZLAB_PLUGIN_NAME); ?></label>
                        <input type="file" class="form-control" name="file" accept=".txt,.csv,.xlsx">
                        <div class="mt-1">
                            <small class="d-block">
                                <?php esc_html_e('Supported files:', BUZZLAB_PLUGIN_NAME); ?> <b class="fw-bold"><?php esc_html_e('csv', BUZZLAB_PLUGIN_NAME); ?>, <?php esc_html_e('excel', BUZZLAB_PLUGIN_NAME); ?>, <?php esc_html_e('txt', BUZZLAB_PLUGIN_NAME); ?></b>
                            </small>
                            <small>
                                <?php esc_html_e('Download all of the template files from here', BUZZLAB_PLUGIN_NAME); ?>
                                <a href="<?php echo buzz_assets('template_files/' . $contactType . '/sample.csv') ?>" title="<?php esc_html_e('Download csv file', BUZZLAB_PLUGIN_NAME); ?>" class="text--primary" download>
                                    <b><?php esc_html_e('csv', BUZZLAB_PLUGIN_NAME); ?>,</b>
                                </a>
                                <a href="<?php echo buzz_assets('template_files/' . $contactType . '/sample.xlsx') ?>" title="<?php esc_html_e('Download excel file', BUZZLAB_PLUGIN_NAME); ?>" class="text--primary" download>
                                    <b><?php esc_html_e('excel', BUZZLAB_PLUGIN_NAME); ?>,</b>
                                </a>
                                <a href="<?php echo buzz_assets('template_files/' . $contactType . '/sample.txt') ?>" title="<?php esc_html_e('Download txt file', BUZZLAB_PLUGIN_NAME); ?>" class="text--primary" download>
                                    <b><?php esc_html_e('txt', BUZZLAB_PLUGIN_NAME); ?></b>
                                </a>
                            </small>
                        </div>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="Submit" class="btn btn--primary w-100 h-45"><?php esc_html_e('Upload', BUZZLAB_PLUGIN_NAME); ?></button>
                </div>
            </form>
        </div>
    </div>
</div>



<div class="modal fade" id="exportModal" tabindex="-1" role="dialog">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-header">
                <h4 class="modal-title"><?php esc_html_e('Export Filter', BUZZLAB_PLUGIN_NAME); ?></h4>
                <button type="button" class="close" data-bs-dismiss="modal" aria-label="Close">
                    <i class="la la-close" aria-hidden="true"></i>
                </button>
            </div>
            <form method="post" action="<?php echo buzz_route_link('contact.export') ?>" id="importForm" enctype="multipart/form-data">
                <?php echo buzz_nonce_field('contact.export') ?>
                <input type="hidden" name="contact_type" value="<?php echo $contactType; ?>">
                <div class="modal-body">
                    <div class="form-group">
                        <label class="fw-bold"><?php esc_html_e('Export Column', BUZZLAB_PLUGIN_NAME); ?></label>
                        <div class="row">
                            <?php
                            if ($contactType == 'email') {
                                unset($columns[array_search('mobile', $columns)]);
                            } elseif ($contactType == 'mobile') {
                                unset($columns[array_search('email', $columns)]);
                            }
                            ?>
                            <?php foreach ($columns as $key => $column) : ?>
                                <div class="col-lg-6 mb-3">
                                    <label><?php esc_html_e(buzz_key_to_title($column), BUZZLAB_PLUGIN_NAME); ?></label>
                                    <input type="checkbox" data-width="100%" data-size="large" data-onstyle="-success" data-offstyle="-danger" data-bs-toggle="toggle" data-height="50" data-on="<?php esc_attr_e('Yes', BUZZLAB_PLUGIN_NAME); ?>" data-off="<?php esc_attr_e('No', BUZZLAB_PLUGIN_NAME); ?>" name="columns[]" value="<?php echo $column ?>" <?php echo $column == 'created_at' || $column == 'updated_at' || $column == 'id' ? 'unchecked' : 'checked' ?>>
                                </div>
                            <?php endforeach ?>
                        </div>
                    </div>
                    <hr>
                    <div class="form-group">
                        <label><?php esc_html_e('Order By', BUZZLAB_PLUGIN_NAME); ?></label>
                        <input type="checkbox" data-width="100%" data-size="large" data-onstyle="-success" data-offstyle="-danger" data-bs-toggle="toggle" data-height="50" data-on="<?php esc_attr_e('ASC', BUZZLAB_PLUGIN_NAME); ?>" data-off="<?php esc_attr_e('DESC', BUZZLAB_PLUGIN_NAME); ?>" name="order_by" <?php if (get_option('buzz_sms_notification')) : ?> checked <?php endif ?>>
                    </div>

                    <div class="form-group">
                        <label><?php esc_html_e('Export Item', BUZZLAB_PLUGIN_NAME); ?></label>
                        <select class="form-control form-control-lg" name="export_item">
                            <option value="10"><?php esc_html_e('10', BUZZLAB_PLUGIN_NAME); ?></option>
                            <option value="50"><?php esc_html_e('50', BUZZLAB_PLUGIN_NAME); ?></option>
                            <option value="100"><?php esc_html_e('100', BUZZLAB_PLUGIN_NAME); ?></option>
                            <?php if ($contactCount > 100) : ?>
                                <option value="<?php echo $contactCount ?>"><?php esc_html_e($contactCount, BUZZLAB_PLUGIN_NAME); ?> <?php esc_html_e('Contacts', BUZZLAB_PLUGIN_NAME); ?>
                                </option>
                            <?php endif ?>
                        </select>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="Submit" class="btn btn--primary w-100 h-45 contactExport"><?php esc_html_e('Export', BUZZLAB_PLUGIN_NAME); ?></button>
                </div>
            </form>
        </div>
    </div>
</div>



<?php
buzz_include('partials/confirmation', ['nonce' => 'admin.contact.status']);
$html = '<button type="button" class="btn btn-outline--primary addBtn"><i class="las la-plus"></i>' . __("Add New", BUZZLAB_PLUGIN_NAME) . '</button>';
$html .= '<button type="button" class="btn btn-outline--info importBtn"><i class="las la-cloud-upload-alt"></i>' . __("Import", BUZZLAB_PLUGIN_NAME) . '</button>';
$html .= '<button type="button" class="btn btn-outline--warning exportBtn"><i class="las la-cloud-download-alt"></i>' . __("Export", BUZZLAB_PLUGIN_NAME) . '</button>';

buzz_push_breadcrumb($html);
?>


<script>
    jQuery(document).ready(function($) {
        "use strict";

        function notify(status, message) {
            iziToast[status]({
                message: message,
                position: "topRight"
            });
        }

        $('.addBtn').on('click', function(e) {
            let addModal = $("#addModal");
            addModal.modal('show');
        });


        $('.editBtn').on('click', function(e) {
            let editModal = $("#editModal");
            let contact = $(this).data('contact');
            editModal.find(".name").val(<?php echo esc_attr('contact.name'); ?>);
            editModal.find(".email").val(<?php echo esc_attr('contact.email'); ?>);
            editModal.find(".mobile").val(<?php echo esc_attr('contact.mobile'); ?>);
            editModal.find(".contact_id").val(<?php echo esc_attr('contact.id'); ?>);
            editModal.modal('show');
        });


        $(".importBtn").on('click', function(e) {
            let importModal = $("#importModal");
            importModal.modal('show');
        });

        $('#importForm').on('submit', function(event) {
            event.preventDefault();
            let formData = new FormData($(this)[0]);
            formData.append("action", "contact_import");
            let time = 0;
            let url = "<?php echo admin_url('/admin-ajax.php') ?>";
            $.ajax({
                url: url,
                method: "POST",
                data: formData,
                cache: false,
                contentType: false,
                processData: false,
                beforeSend: function() {
                    $('#importModal').find('.modal-header').addClass('animate-border');
                },
                complete: function(e) {
                    $('#importModal').find('.modal-header').removeClass('animate-border');
                },
                success: function(response) {
                    if (response.success) {
                        notify('success', response.message);
                        $("#importModal").modal('hide');
                        setTimeout(() => {
                            location.reload()
                        }, 2000);
                    } else if (!response.success) {
                        notify('error', response.message);
                    } else {
                        $.each(response.errors, function(index, value) {
                            notify('error', value);
                        });
                    }
                },

            });
        });

        $(".exportBtn").on('click', function(e) {
            let modal = $("#exportModal");
            modal.modal('show')
        });

    });
</script>