<?php
buzz_layout('admin/layouts/master');
?>

<div class="row">
    <div class="col-12">
        <div class="card b-radius--10">
            <div class="card-body p-0">
                <div class="table-responsive--md table-responsive">
                    <table class="table--light style--two table">
                        <thead>
                            <tr>
                                <th><?php esc_html_e('Name', BUZZLAB_PLUGIN_NAME) ?></th>
                                <th><?php esc_html_e('Total Contacts', BUZZLAB_PLUGIN_NAME) ?></th>
                                <th><?php esc_html_e('Status', BUZZLAB_PLUGIN_NAME) ?></th>
                                <th><?php esc_html_e('Action', BUZZLAB_PLUGIN_NAME) ?></th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php 
                            foreach ($groups->data as $group) { 
                            ?>
                                <tr>
                                    <td> <?php esc_html_e($group->name) ?></td>
                                    <td><?php esc_html_e($group->contact_count) ?></td>
                                    <td>
                                        <?php
                                        if ($group->status) {
                                            echo '<span class="text--small badge badge--success">' . __("Active", BUZZLAB_PLUGIN_NAME) . '</span>';
                                        } else {
                                            echo '<span class="text--small badge badge--danger">' . __("Inactive", BUZZLAB_PLUGIN_NAME) . '</span>';
                                        } ?>
                                    </td>
                                    <td>
                                        <div class="button--group">

                                            <button type="button" data-group="<?php esc_attr_e(json_encode($group)); ?>" class="btn btn-sm btn-outline--primary editBtn">
                                                <i class="la la-pencil"></i> <?php esc_html_e('Edit', BUZZLAB_PLUGIN_NAME); ?>
                                            </button>

                                            <a class="btn btn-sm btn-outline--info" 
                                            href="<?php echo buzz_route_link('admin.group.contact.view'); ?>&amp;id=<?php echo intval($group->id); ?>&amp;type=<?php echo intval($groupType); ?>"
                                            >
                                                <i class="las la-desktop"></i><?php esc_html_e('View Contact', BUZZLAB_PLUGIN_NAME); ?>  
                                            </a>

                                            <?php if ($group->status == 0) { ?>
                                                <button class="btn btn-sm btn-outline--success ms-1 confirmationBtn" data-question="<?php esc_attr_e('Are you sure to active this group?', BUZZLAB_PLUGIN_NAME); ?>" data-action="<?php echo buzz_route_link('admin.group.status'); ?>&amp;id=<?php echo intval($group->id); ?>">
                                                    <i class="la la-eye"></i> <?php esc_html_e('Active', BUZZLAB_PLUGIN_NAME); ?>
                                                </button>
                                            <?php } else { ?>
                                                <button class="btn btn-sm btn-outline--danger ms-1 confirmationBtn" data-question="<?php esc_attr_e('Are you sure to inactive this group?', BUZZLAB_PLUGIN_NAME); ?>" data-action="<?php echo buzz_route_link('admin.group.status'); ?>&amp;id=<?php echo intval($group->id); ?>">
                                                    <i class="la la-eye-slash"></i> <?php esc_html_e('Inactive', BUZZLAB_PLUGIN_NAME); ?>
                                                </button>
                                            <?php } ?>
                                        </div>
                                    </td>
                                </tr>
                            <?php }  ?>
                            <?php if (buzz_check_empty($groups->data)) { ?>
                                <tr>
                                    <td colspan="100%" class="text-center"><?php esc_html_e('Data Not Found', BUZZLAB_PLUGIN_NAME); ?></td>
                                </tr>
                            <?php } ?>
                        </tbody>
                    </table>
                </div>
            </div>
            <?php if (@$groups->links) { ?>
                <div class="card-footer">
                    <?php echo wp_kses($groups->links, buzz_allowed_html()); ?>
                </div>
            <?php } ?>
        </div>
    </div>
</div>

<!-- Contact Add Modal -->
<div class="modal fade" id="addModal">
    <div class="modal-dialog modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h4 class="modal-title"><?php esc_html_e('Add New Group', BUZZLAB_PLUGIN_NAME) ?></h4>
                <button type="button" class="close" data-bs-dismiss="modal" aria-label="Close">
                    <i class="la la-times" aria-hidden="true"></i>
                </button>
            </div>
            <form method="POST" action="<?php echo buzz_route_link('admin.group.store') ?>">
                <?php buzz_nonce_field('admin.group.store'); ?>
                <input type="hidden" name="type" value="<?php esc_attr_e($groupType); ?>">

                <div class="modal-body">
                    <div class="form-group">
                        <label class="required"><?php esc_html_e('Name', BUZZLAB_PLUGIN_NAME); ?></label>
                        <input type="text" class="form-control" name="name" value="<?php echo esc_attr(buzz_old('name')); ?>">
                    </div>
                    
                </div>
                <div class="modal-footer">
                    <button type="submit" class="btn btn--primary w-100 h-45" id="btn-save"><?php esc_html_e('Submit', BUZZLAB_PLUGIN_NAME); ?></button>
                </div>
            </form>
        </div>
    </div>
</div>

<!-- Contact Update Modal -->
<div class="modal fade" id="editModal">
    <div class="modal-dialog modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h4 class="modal-title"><?php esc_html_e('Edit Group', BUZZLAB_PLUGIN_NAME) ?></h4>
                <button type="button" class="close" data-bs-dismiss="modal" aria-label="Close">
                    <i class="la la-times" aria-hidden="true"></i>
                </button>
            </div>
            <form method="POST" action="<?php echo buzz_route_link('admin.group.update');?>" id="form">
                <?php buzz_nonce_field('admin.group.update'); ?>
                <input type="hidden" name="type" value="<?php esc_attr_e($groupType); ?>">

                <div class="modal-body">
                    <div class="form-group">
                        <label><?php esc_html_e('Name', BUZZLAB_PLUGIN_NAME); ?></label>
                        <input type="text" class="form-control name" name="name" value="<?php echo esc_attr(buzz_old('name')); ?>">
                    </div>
                </div>
                <div class="modal-footer">
                    <input type="hidden" class="group_id" name="id">
                    <button type="submit" class="btn btn--primary w-100 h-45" id="btn-save"><?php esc_html_e('Submit', BUZZLAB_PLUGIN_NAME); ?></button>
                </div>
            </form>
        </div>
    </div>
</div>

<?php
buzz_include('partials/confirmation', ['nonce' => 'admin.group.status']);
$html = '<a class="btn btn-outline--primary addBtn"><i class="las la-plus"></i>' . __("Add New", BUZZLAB_PLUGIN_NAME) . '</a>';
buzz_push_breadcrumb($html);
?>

<script>
    jQuery(document).ready(function($) {
        "use strict";

        $('.addBtn').on('click', function(e) {
            let addModal = $("#addModal");
            addModal.modal('show');
        });


        $('.editBtn').on('click', function(e) {
            let editModal = $("#editModal");
            let group = $(this).data('group');
            editModal.find(".name").val(<?php echo esc_attr('group.name'); ?>);
            editModal.find(".group_id").val(<?php echo esc_attr('group.id'); ?>);
            editModal.modal('show');
        });

    });
</script>